==> jc-1.4.0.tar.gz: javax/swing/table/DefaultTableCellRenderer__24UIResource.h <==
// public class javax.swing.table.DefaultTableCellRenderer$UIResource

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class d7ef9fe7ff454b0d javax_swing_JLabel
// @dep_class 1e984e0da8743570 javax_swing_table_DefaultTableCellRenderer
// @dep_class b430e89a6a85eb97 javax_swing_table_DefaultTableCellRenderer__24UIResource

// header file dependencies
// @dep_header javax_swing_table_DefaultTableCellRenderer

#include "javax/swing/table/DefaultTableCellRenderer.h"

#ifndef _JC_javax_swing_table_DefaultTableCellRenderer__24UIResource_H_
#define _JC_javax_swing_table_DefaultTableCellRenderer__24UIResource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$sub_refs	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$sub_refs;
typedef struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$sub_nonrefs	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$sub_nonrefs;
typedef struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$refs	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$refs;
typedef struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$nonrefs	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$nonrefs;
typedef struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$object	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$object;

typedef const struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vmethods	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vmethods;
typedef const struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vtable	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vtable;
typedef const struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vtype	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vtype;

// Constructors
extern void _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$object *);

// Virtual methods structure
struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JLabel$vmethods	javax_swing_JLabel;
	_jc_javax_swing_table_DefaultTableCellRenderer$vmethods	javax_swing_table_DefaultTableCellRenderer;
	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vmethods	javax_swing_table_DefaultTableCellRenderer__24UIResource;
};

// Vtype
struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$refs {
    _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$sub_refs	javax_swing_table_DefaultTableCellRenderer__24UIResource;
    _jc_javax_swing_table_DefaultTableCellRenderer$sub_refs	javax_swing_table_DefaultTableCellRenderer;
    _jc_javax_swing_JLabel$sub_refs	javax_swing_JLabel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JLabel$sub_nonrefs	javax_swing_JLabel;
    _jc_javax_swing_table_DefaultTableCellRenderer$sub_nonrefs	javax_swing_table_DefaultTableCellRenderer;
    _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$sub_nonrefs	javax_swing_table_DefaultTableCellRenderer__24UIResource;
};

// Object instance structure
struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$object {
	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vtype	*vtype;
	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vtype _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_table_DefaultTableCellRenderer__24UIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$class_object;

#endif	/* _JC_javax_swing_table_DefaultTableCellRenderer__24UIResource_H_ */

==> jc-1.4.5.tar.gz: javax/swing/table/DefaultTableCellRenderer__24UIResource.h <==
// public class javax.swing.table.DefaultTableCellRenderer$UIResource

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class d7ef9fe7ff454b0d javax_swing_JLabel
// @dep_class 1e984e0da8743570 javax_swing_table_DefaultTableCellRenderer
// @dep_class b430e89a6a85eb97 javax_swing_table_DefaultTableCellRenderer__24UIResource

// header file dependencies
// @dep_header javax_swing_table_DefaultTableCellRenderer

#include "javax/swing/table/DefaultTableCellRenderer.h"

#ifndef _JC_javax_swing_table_DefaultTableCellRenderer__24UIResource_H_
#define _JC_javax_swing_table_DefaultTableCellRenderer__24UIResource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$sub_refs	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$sub_refs;
typedef struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$sub_nonrefs	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$sub_nonrefs;
typedef struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$refs	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$refs;
typedef struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$nonrefs	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$nonrefs;
typedef struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$object	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$object;

typedef const struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vmethods	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vmethods;
typedef const struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vtable	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vtable;
typedef const struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vtype	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vtype;

// Constructors
extern void _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JLabel$vmethods	javax_swing_JLabel;
	_jc_javax_swing_table_DefaultTableCellRenderer$vmethods	javax_swing_table_DefaultTableCellRenderer;
	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vmethods	javax_swing_table_DefaultTableCellRenderer__24UIResource;
};

// Vtype
struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$refs {
    _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$sub_refs	javax_swing_table_DefaultTableCellRenderer__24UIResource;
    _jc_javax_swing_table_DefaultTableCellRenderer$sub_refs	javax_swing_table_DefaultTableCellRenderer;
    _jc_javax_swing_JLabel$sub_refs	javax_swing_JLabel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JLabel$sub_nonrefs	javax_swing_JLabel;
    _jc_javax_swing_table_DefaultTableCellRenderer$sub_nonrefs	javax_swing_table_DefaultTableCellRenderer;
    _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$sub_nonrefs	javax_swing_table_DefaultTableCellRenderer__24UIResource;
};

// Object instance structure
struct _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$object {
	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vtype	*vtype;
	_jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$vtype _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_table_DefaultTableCellRenderer__24UIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_table_DefaultTableCellRenderer__24UIResource$class_object;

#endif	/* _JC_javax_swing_table_DefaultTableCellRenderer__24UIResource_H_ */
